Reflection
==========

.. centered::
  Cursed by the dimensionality of your nuisance space?

.. centered::
  Wasted by Markov chains that reject your simulations?

.. centered::
  Exhausted from messing with simplistic models, because your inference algorithm cannot handle the truth?

.. image:: https://source.unsplash.com/Qa2tSHWgh84/600x400
  :align: center

.. centered::
  Try swyft for some pain relief.
